import { DiagnosticCode } from '@astrojs/compiler/shared/diagnostics.js';
import { AstroErrorCodes } from './errors-data.js';
/**
 * Get the line and character based on the offset
 * @param offset The index of the position
 * @param text The text for which the position should be retrived
 */
export declare function positionAt(offset: number, text: string): {
    line: number;
    column: number;
};
/** Coalesce any throw variable to an Error instance. */
export declare function createSafeError(err: any): Error;
export declare function normalizeLF(code: string): string;
export declare function getErrorDataByCode(code: AstroErrorCodes | DiagnosticCode): {
    name: string;
    data: {
        readonly code: 1000;
    } | {
        readonly code: 3001;
        readonly message: "Redirects are only available when using output: 'server'. Update your Astro config if you need SSR features.";
        readonly hint: "See https://docs.astro.build/en/guides/server-side-rendering/#enabling-ssr-in-your-project for more information on how to enable SSR.";
    } | {
        readonly code: 3002;
        readonly message: (adapterName: string) => string;
    } | {
        readonly code: 3003;
        readonly message: "Astro.clientAddress is only available when using output: 'server'. Update your Astro config if you need SSR features.";
        readonly hint: "See https://docs.astro.build/en/guides/server-side-rendering/#enabling-ssr-in-your-project for more information on how to enable SSR.";
    } | {
        readonly code: 3004;
        readonly message: (pathName: string) => string;
        readonly hint: (possibleRoutes: string[]) => string;
    } | {
        readonly code: 3005;
        readonly message: (route: string | undefined, returnedValue: string) => string;
        readonly hint: "See https://docs.astro.build/en/guides/server-side-rendering/#response for more information.";
    } | {
        readonly code: 3006;
        readonly message: (componentName: string) => string;
    } | {
        readonly code: 3007;
        readonly message: (componentName: string, componentExtension: string | undefined, plural: boolean, validRenderersCount: number) => string;
        readonly hint: (probableRenderers: string) => string;
    } | {
        readonly code: 3008;
        readonly message: (componentName: string, clientDirective: string, rendererName: string) => string;
        readonly hint: "See https://docs.astro.build/en/reference/integrations-reference/#addrenderer-option for more information on how to configure your renderer.";
    } | {
        readonly code: 3009;
        readonly message: (componentName: string) => string;
        readonly hint: (probableRenderers: string) => string;
    } | {
        readonly code: 3010;
        readonly message: (paramType: any) => string;
        readonly hint: "See https://docs.astro.build/en/reference/api-reference/#getstaticpaths for more information on getStaticPaths.";
    } | {
        readonly code: 3011;
        readonly message: (returnType: any) => string;
        readonly hint: "See https://docs.astro.build/en/reference/api-reference/#getstaticpaths for more information on getStaticPaths.";
    } | {
        readonly code: 3012;
        readonly message: "The RSS helper has been removed from getStaticPaths! Try the new @astrojs/rss package instead.";
        readonly hint: "See https://docs.astro.build/en/guides/rss/ for more information.";
    } | {
        readonly code: 3013;
        readonly message: "Missing or empty required params property on getStaticPaths route";
        readonly hint: "See https://docs.astro.build/en/reference/api-reference/#getstaticpaths for more information on getStaticPaths.";
    } | {
        readonly code: 3014;
        readonly message: (key: string, value: any) => string;
        readonly hint: "See https://docs.astro.build/en/reference/api-reference/#getstaticpaths for more information on getStaticPaths.";
    } | {
        readonly code: 3015;
        readonly message: "getStaticPaths() function is required for dynamic routes. Make sure that you `export` a `getStaticPaths` function from your dynamic route.";
        readonly hint: "See https://docs.astro.build/en/core-concepts/routing/#dynamic-routes for more information on dynamic routes.\n\nAlternatively, set `output: \"server\"` in your Astro config file to switch to a non-static server build.\nSee https://docs.astro.build/en/guides/server-side-rendering/ for more information on non-static rendering.";
    } | {
        readonly code: 3016;
        readonly message: (slotName: string) => string;
    } | {
        readonly code: 3017;
        readonly message: "Cannot use `output: 'server'` without an adapter. Please install and configure the appropriate server adapter for your final deployment.";
        readonly hint: "See https://docs.astro.build/en/guides/server-side-rendering/ for more information.";
    } | {
        readonly code: 3018;
        readonly message: (componentName: string) => string;
        readonly hint: "Please make sure the component is properly imported.";
    } | {
        readonly code: 4000;
    } | {
        readonly code: 4001;
    } | {
        readonly code: 5000;
    } | {
        readonly code: 5001;
        readonly message: (importName: string) => string;
        readonly hint: "This is often caused by a typo in the import path. Please make sure the file exists.";
    } | {
        readonly code: 5002;
        readonly message: (globPattern: string) => string;
        readonly hint: "See https://docs.astro.build/en/guides/imports/#glob-patterns for more information on supported glob patterns.";
    } | {
        readonly code: 6000;
    } | {
        readonly code: 6001;
    } | {
        readonly code: 7000;
    } | {
        readonly code: 7001;
        readonly message: (configFile: string) => string;
    } | {
        readonly code: 7002;
        readonly message: (legacyConfigKey: string) => string;
        readonly hint: "Please update your configuration to the new format!\nSee https://astro.build/config for more information.";
    } | {
        readonly code: 99999;
    };
} | undefined;
